| predict.coxkl | R Documentation |
coxkl ObjectComputes linear predictors for new data based on a fitted coxkl model.
If eta is supplied, predictions are returned for those eta values;
otherwise predictions are returned for all fitted etas. Linear interpolation
is applied if an intermediate eta value is requested.
## S3 method for class 'coxkl'
predict(object, newz, eta = NULL, ...)
object |
A fitted model object of class |
newz |
A numeric matrix or data frame of new covariates (must match the dimension of the training design matrix used to fit the model). |
eta |
Optional numeric vector of |
... |
Additional arguments. |
The linear predictors are computed as as.matrix(newz) %*% beta.
A numeric matrix of linear predictors with one column per eta (sorted ascending).
coef.coxkl
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.