| predict.coxkl_enet | R Documentation |
Computes linear predictors for new data using a fitted coxkl_enet model.
If lambda is supplied, predictions are returned for those lambda
values; otherwise predictions are returned for all fitted lambdas. When a
requested lambda lies between fitted values, coefficients are linearly
interpolated.
## S3 method for class 'coxkl_enet'
predict(object, newz, lambda = NULL, ...)
object |
A fitted model object of class |
newz |
A numeric matrix or data frame of new covariates (same columns as in training data). |
lambda |
Optional numeric value(s) specifying the regularization parameter(s)
for which to predict. If |
... |
Additional arguments. |
The linear predictors are computed as as.matrix(newz) %*% beta.
A numeric matrix of linear predictors.
Each column corresponds to one lambda, sorted in descending order.
coef.coxkl_enet
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.