Example high-dimensional survival data
ExampleData_highdim.RdA simulated survival dataset in a high-dimensional linear setting with 50 covariates (6 signals + 44 AR(1) noise), Weibull baseline hazard, and controlled censoring. Includes internal train/test sets, and an external-data–estimated coefficient vector.
Usage
data(ExampleData_highdim)Format
A list containing the following elements:
- train
A list with components:
- z
Data frame of size \(n_\mathrm{train}\times 50\) with covariates
Z1–Z50.- status
Vector of event indicators (
1=event,0=censored).- time
Numeric vector of observed times \(\min(T, C)\).
- stratum
Vector of stratum labels (here all
1).
- test
A list with the same structure as
train, with size \(n_\mathrm{test}\times 50\) forz.- beta_external
Numeric vector (length 50, named
Z1–Z50) of Cox coefficients estimated on an external dataset using onlyZ1–Z6and expanded to length 50 (zeros forZ7–Z50).
Details
Data-generating mechanism:
Covariates: 50 variables with signals
Z1–Z6and noiseZ7–Z50.Z1,Z2~ bivariate normal with AR(1) correlation \(\rho=0.5\).Z3,Z4~ independent Bernoulli(0.5).Z5~ \(N(2,1)\),Z6~ \(N(-2,1)\) (group indicator fixed at 1).Z7–Z50~ multivariate normal with AR(1) correlation \(\rho=0.5\).
True coefficients: \(\beta = (0.3,-0.3,0.3,-0.3,0.3,-0.3,0,\ldots,0)\) (length 50).
Event times: Weibull baseline hazard \(h_0(t)=\lambda\nu\, t^{\nu-1}\) with \(\lambda=1\), \(\nu=2\). Given linear predictor \(\eta = Z^\top \beta\), draw \(U\sim\mathrm{Unif}(0,1)\) and set $$T = \left(\frac{-\log U}{\lambda\, e^{\eta}}\right)^{1/\nu}.$$
Censoring: \(C\sim \mathrm{Unif}(0,\text{ub})\) with
ubtuned iteratively to achieve the target censoring rate (internal:0.70; external:0.50). Observed time is \(\min(T,C)\), status is \(\mathbf{1}\{T \le C\}\).External coefficients: Fit a Cox model
Surv(time, status) ~ Z1 + ... + Z6on the external data (Breslow ties), then place the estimated coefficients into a length-50 vector (zeros elsewhere).
Examples
data(ExampleData_highdim)
head(ExampleData_highdim$train$z)
#> Z1 Z2 Z3 Z4 Z5 Z6 Z7 Z8
#> 1 0.8341847 1.2548397 0 1 1.230205 -1.379354 0.29715594 -0.1846824
#> 2 -0.3289623 -0.5440874 1 1 3.009319 -2.027648 0.06107997 -0.7877205
#> 3 -3.1720374 -0.4180468 1 0 2.387088 -2.780979 -0.85233051 -1.3215052
#> 4 0.1281318 -0.8776107 1 1 2.521981 -2.184659 -0.71413081 0.9238884
#> 5 -1.2284273 -0.7566494 0 1 1.762825 -2.555997 -1.87046640 -1.2583798
#> 6 0.8213465 1.4635825 1 1 1.887867 -1.232408 0.02923435 -0.5281927
#> Z9 Z10 Z11 Z12 Z13 Z14 Z15
#> 1 1.0982052 0.4904068 0.5025818 0.9381855 0.4799360 0.3437346 0.4320523
#> 2 -1.2572372 -0.7316574 -1.2545473 0.3399338 -2.3401946 -0.6721147 -0.7741806
#> 3 -0.8917207 0.5492385 1.2280196 -0.4813451 0.4396726 0.5759964 -0.3324509
#> 4 0.2700611 -0.5746064 -0.3090879 0.2892202 1.2383940 1.4950458 -0.2552768
#> 5 -0.8879612 -1.1652591 -1.3263840 0.1811636 1.0627427 0.7584533 0.8554499
#> 6 -1.3821379 0.7588488 1.1300513 -0.3151114 0.2124996 -0.7406890 -0.6363002
#> Z16 Z17 Z18 Z19 Z20 Z21
#> 1 0.8633326 0.7533490 1.0215138 1.51246470 0.94004928 -0.2257148
#> 2 -0.0393791 -0.5752974 -0.8462299 -0.16716546 -1.79317838 -0.5395597
#> 3 -1.3388491 0.1427682 -0.2026194 1.60425188 2.47017074 0.4935123
#> 4 -0.5982543 0.1761313 -0.9428526 -0.98955493 1.55572861 1.5238076
#> 5 -0.6517327 -1.5715401 -0.8141908 -0.03304642 -0.01628385 -1.3252785
#> 6 -1.2840411 0.1747675 -0.1237938 0.29138370 0.14430507 0.6488622
#> Z22 Z23 Z24 Z25 Z26 Z27 Z28
#> 1 1.2631874 -0.8176610 -1.3054956 -2.59423303 -1.0819914 -1.7759045 -0.3130515
#> 2 0.2219920 -1.3828436 0.2169797 0.69637444 0.1963209 0.3101008 0.1045186
#> 3 -0.5419710 -0.5775182 -0.9108406 0.18592158 1.3871736 0.2519995 0.9655862
#> 4 0.7762024 -0.3625580 -1.6130505 -1.06893004 0.3174351 1.0103921 -0.4376606
#> 5 -0.6695136 -0.5061301 0.0331691 -0.73308691 0.2968483 0.3420247 0.3465201
#> 6 1.7856642 -0.8147424 -1.9587034 -0.05948988 -1.1346326 0.2344805 -0.5347376
#> Z29 Z30 Z31 Z32 Z33 Z34
#> 1 0.1450573 -0.3522625 1.3583706 -1.1354976 -0.08176453 0.90301566
#> 2 0.1736015 0.1832902 -1.0431791 -1.6964999 -1.59347993 -2.33205882
#> 3 -0.3261791 -0.2129586 -1.1342233 -0.4226060 0.96752663 -0.11062591
#> 4 -1.0527535 -0.6244569 -0.3397628 1.1462418 0.45662572 0.05212241
#> 5 -0.7050586 -0.8054282 -0.8825711 -1.4828052 0.14471226 0.12423004
#> 6 0.1302796 0.4279924 0.5541080 0.5823341 -0.53471012 -0.37043642
#> Z35 Z36 Z37 Z38 Z39 Z40
#> 1 -0.33873339 0.90547061 0.9280060 -0.1313232 -0.5279536 0.7480440
#> 2 -2.03014417 -1.01837762 -0.9425266 -0.7156324 -1.2498089 0.2309582
#> 3 -0.04469714 -0.05222202 -0.8417919 -0.5504270 0.6418680 1.4240399
#> 4 -0.21573577 -0.91514694 0.1936167 0.4127731 0.1198166 0.2578691
#> 5 1.04310306 1.31328693 0.1785853 -2.0694800 -2.3911914 -1.2461304
#> 6 0.79710530 0.36294685 0.8356093 0.3896813 -0.9716663 -0.4682918
#> Z41 Z42 Z43 Z44 Z45 Z46
#> 1 0.626297434 0.04292509 0.612210812 -1.2068899 -1.03689495 -0.63210927
#> 2 1.043110114 0.51952039 -0.709333558 1.5400533 1.40551197 2.54570573
#> 3 0.009322651 1.00946381 0.201396249 0.7608163 0.60980799 0.07967597
#> 4 0.375786446 -0.07833188 0.004788632 1.4215175 1.26539924 -1.54623996
#> 5 -0.205232458 1.02566517 1.481439960 2.0989416 0.04201603 -0.39717619
#> 6 -0.662404892 0.11826542 -0.038936256 -1.8301693 -1.24983745 -0.61987848
#> Z47 Z48 Z49 Z50
#> 1 -0.75296206 -1.466023 -0.6107553 0.5837428
#> 2 1.88849816 2.157199 0.6465888 -0.3936396
#> 3 0.25028165 -1.490555 -0.6696376 0.6741264
#> 4 1.26147753 -0.467992 1.0971287 1.3047671
#> 5 0.01994461 -0.493669 -0.3828498 0.5840523
#> 6 0.28317437 1.268658 1.8107407 0.1405356
table(ExampleData_highdim$train$status)
#>
#> 0 1
#> 144 56
summary(ExampleData_highdim$train$time)
#> Min. 1st Qu. Median Mean 3rd Qu. Max.
#> 0.002357 0.118257 0.226289 0.229358 0.339145 0.575841
head(ExampleData_highdim$test$z)
#> Z1 Z2 Z3 Z4 Z5 Z6 Z7 Z8
#> 1 -0.8755157 -0.19970306 1 0 2.4542939 -3.280559 0.13764707 -0.29951270
#> 2 0.8236265 0.07930611 1 0 1.4890025 -3.938458 0.22951537 -0.27756548
#> 3 0.9263612 -0.01997836 1 1 0.6358499 -3.195342 0.52670452 0.05328195
#> 4 0.1850598 -0.70337717 0 1 2.2810817 -4.434547 0.79721336 -0.31697608
#> 5 0.3474487 -0.42614590 0 0 0.7145202 -2.830799 0.07278411 -1.42828452
#> 6 -0.8803044 -0.91163905 0 0 2.4224220 -2.329654 1.28874933 -0.30053293
#> Z9 Z10 Z11 Z12 Z13 Z14 Z15
#> 1 -1.8593895 -0.1736244 -0.03612483 1.7472408 1.7360144 1.6572400 0.7806403
#> 2 0.2713486 0.2236954 -1.35911106 -0.3897491 -0.3989989 0.1117077 -0.2587745
#> 3 0.2293453 -0.5221144 -0.41978900 -0.6275746 -1.0680740 0.5019976 0.9790618
#> 4 -1.0048234 -1.1459370 0.26200422 0.4194908 2.3126135 0.6683572 0.6028322
#> 5 -0.4451788 0.4631919 1.05744097 1.3881108 1.2026630 -1.8938359 -1.0292716
#> 6 -0.7162089 1.0104155 -0.38368599 0.4486694 -0.6833364 -1.1513100 -0.1524856
#> Z16 Z17 Z18 Z19 Z20 Z21
#> 1 1.0419634 1.0014758 0.87853402 1.20154893 0.70993166 0.6926842
#> 2 2.5036764 1.0563505 0.49304476 0.83883757 0.53522160 1.7725695
#> 3 1.9456876 0.2410226 0.93140905 -0.50013494 -0.24039917 -1.3943652
#> 4 0.6518553 0.5833234 0.56267706 -0.68226000 -0.49821852 0.4635016
#> 5 -1.1394870 -0.6498890 -0.63055354 -0.67106393 -1.36795205 0.7937763
#> 6 -2.1706700 -0.6895768 -0.09568807 0.01370934 0.07330939 1.4275766
#> Z22 Z23 Z24 Z25 Z26 Z27
#> 1 0.1522400 0.72886816 0.96106634 0.75738274 -0.24679473 0.3333615
#> 2 0.1914927 -0.24217057 -1.69998202 -0.83921306 -0.83895440 0.2525735
#> 3 0.2215496 -3.38045379 -1.67431365 -0.08341914 -1.07549132 -0.9306513
#> 4 0.8072025 -0.06383284 1.40726238 0.61687798 0.42779651 0.3411079
#> 5 -0.8177690 -0.07890665 1.10520120 0.75595253 2.58006781 1.6626002
#> 6 1.1219039 2.08552715 -0.01395411 -0.58492795 0.05189429 0.3238361
#> Z28 Z29 Z30 Z31 Z32 Z33
#> 1 1.8533162 1.1413543 0.006618972 -0.31956804 0.221347062 0.01912242
#> 2 -0.3164956 -1.3575425 0.098572849 0.53449844 -0.008900405 -1.03863804
#> 3 -1.4797537 -0.3794754 -0.995543024 -1.07427224 0.071562637 -1.64276895
#> 4 -0.1274482 -0.4986956 -1.922319725 -0.84184222 -0.806627329 0.19492516
#> 5 1.3229320 0.9924067 -0.181815965 0.04308887 1.322061805 0.33903185
#> 6 -0.9531971 -0.7657889 0.221706398 -0.39189299 -0.107754578 0.14435895
#> Z34 Z35 Z36 Z37 Z38 Z39
#> 1 0.02259753 -0.03638311 1.31072107 0.63267465 0.70821261 -0.9644446
#> 2 -0.83534512 -1.02532257 1.42087476 1.59472721 0.99560368 0.8583339
#> 3 -1.88285945 -1.23116307 -0.74063599 -0.07947944 0.84127101 0.6270051
#> 4 -0.57991673 -0.05609040 -0.03119781 -0.18212746 -0.03795407 1.4248389
#> 5 0.96870265 0.25522277 0.44204637 0.61391922 1.20862465 0.8528802
#> 6 -0.27541315 1.29134035 2.20868594 1.90517098 2.78024828 1.5704774
#> Z40 Z41 Z42 Z43 Z44 Z45
#> 1 0.22510720 0.007031161 0.7480677 -0.33153709 -0.1101352 -0.4382325
#> 2 -0.18666426 -0.453598905 0.3280036 -0.07132729 -0.2260509 -1.3126325
#> 3 0.41890927 -0.893598361 -2.9933830 -0.48448676 -0.1082089 -0.6425374
#> 4 2.43427290 -0.059044636 -0.2373969 1.03315480 0.6519150 0.4775821
#> 5 0.07008611 -0.466548212 -1.4381315 -1.17389378 -0.8892987 -1.9979700
#> 6 1.82803873 0.190203105 0.5919327 -0.88877615 -0.4811745 0.6985946
#> Z46 Z47 Z48 Z49 Z50
#> 1 -0.80117966 0.3576286 -1.0226513 0.301427228 1.5643462
#> 2 -0.06452281 0.2829715 1.0356304 0.984220152 -0.4857993
#> 3 -1.16150511 -0.4833850 -0.3193366 -0.001306896 0.0298568
#> 4 -0.41523841 -0.1098118 1.3527896 1.375761270 2.1009230
#> 5 -0.71063502 1.2419492 1.5455219 -0.117504888 -0.3591661
#> 6 0.82786996 -0.3889966 -1.9303816 -1.512722570 -1.8478961
table(ExampleData_highdim$test$status)
#>
#> 0 1
#> 1376 624
summary(ExampleData_highdim$test$time)
#> Min. 1st Qu. Median Mean 3rd Qu. Max.
#> 0.0003132 0.1309088 0.2467850 0.2605349 0.3766332 0.6122603