| coef.coxkl | R Documentation |
coxkl ObjectExtracts the estimated regression coefficients (beta) from a fitted
coxkl object. Optionally, a value (or vector) of eta can be
supplied. If the requested eta values are not in the fitted sequence,
linear interpolation is performed between the nearest neighboring eta
values; out-of-range requests error.
## S3 method for class 'coxkl'
coef(object, eta = NULL, ...)
object |
An object of class |
eta |
Optional numeric value or vector specifying the |
... |
Additional arguments (currently ignored). |
A numeric matrix of regression coefficients.
Each column corresponds to one value of eta, sorted in ascending order.
data(ExampleData_lowdim)
train_dat_lowdim <- ExampleData_lowdim$train
beta_external_good_lowdim <- ExampleData_lowdim$beta_external_good
eta_list <- generate_eta(method = "exponential", n = 5, max_eta = 5)
model <- coxkl(z = train_dat_lowdim$z,
delta = train_dat_lowdim$status,
time = train_dat_lowdim$time,
stratum = train_dat_lowdim$stratum,
beta = beta_external_good_lowdim,
etas = eta_list)
coef(model)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.