| coef.coxkl_ridge | R Documentation |
coxkl_ridge ObjectExtracts the estimated regression coefficients (beta) from a fitted
coxkl_ridge object. Optionally, one or more lambda values can be
supplied. If requested lambda values are not in the fitted sequence,
linear interpolation is performed between nearest neighbors; out-of-range
requests error.
## S3 method for class 'coxkl_ridge'
coef(object, lambda = NULL, ...)
object |
An object of class |
lambda |
Optional numeric value or vector specifying the regularization
parameter(s) for which to extract (or interpolate) coefficients. If |
... |
Additional arguments (currently ignored). |
A numeric matrix of regression coefficients.
Each column corresponds to one value of lambda, sorted in descending order.
data(ExampleData_highdim)
train_dat_highdim <- ExampleData_highdim$train
beta_external_highdim <- ExampleData_highdim$beta_external
model_ridge <- coxkl_ridge(z = train_dat_highdim$z,
delta = train_dat_highdim$status,
time = train_dat_highdim$time,
beta = beta_external_highdim,
eta = 1)
coef(model_ridge)[1:5, 1:10]
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.