Predict Linear Predictors from a coxkl Object
predict.coxkl.RdComputes linear predictors for new data based on a fitted coxkl model.
If eta is supplied, predictions are returned for those eta values;
otherwise predictions are returned for all fitted etas. Linear interpolation
is applied if an intermediate eta value is requested.
Usage
# S3 method for class 'coxkl'
predict(object, newz, eta = NULL, ...)Arguments
- object
A fitted model object of class
"coxkl".- newz
A numeric matrix or data frame of new covariates (must match the dimension of the training design matrix used to fit the model).
- eta
Optional numeric vector of
etavalue(s) for which to predict. IfNULL, predictions for all fittedetavalues are returned.- ...
Additional arguments.